==> healthcheck_1.2.1-0.tar.gz: healthcheck-1.2.1/src/opt/healthcheck/gn_functions.py <==
# -*- coding: utf-8 -*-
import os
import dbus

def funcAccel():
	print "** Start Function - Accel Co-ords **"
        f = open("/sys/class/i2c-adapter/i2c-3/3-001d/coord", 'r')
        coords = [int(w) for w in f.readline().split()]
        f.close()
        print " ** Getting orientation**"
        b = os.popen('run-standalone.sh dbus-send --system --type=signal /com/nokia/mce/signal com.nokia.mce.signal.sig_device_orientation_ind').read()
        coords = str(coords)
        jaccel = str(coords) + str(b)
	return jaccel

def funcBatchrg():
        print "** Start Function - Battery Charge **"
        gl = os.popen('hal-device bme | awk \'/l.p/ {perc = $3}; /s_c/ {isch = $3} END if (isch == "false") {print perc" %"} else {print "Charging"}\'').read()
        gl = gl.strip()
        return gl

def funcBatLastChrg():
        print " ** Start Function - battery last charge**"
	gl = os.popen('hal-device bme | awk \'/g.la/ {print $3" mAh"}\'').read()
	return gl.strip()

def funcBattcurr():
        print "** Start Function - Battery Current **"
        gl = os.popen('hal-device bme | awk \'/g.c/ {print $3" mAh"}\'').read()
        gl = gl.strip()
        return gl

def funcCamState():
        print "** Start Function - Cam Shutter State **"
        gl = os.popen('cat /sys/devices/platform/gpio-switch/cam_shutter/state').read()
        gl = gl.strip()
        return gl

def funcFMTrans():
        print "** Start Function - FM Transmitter power level **"
        ge = os.popen('cat /sys/class/i2c-adapter/i2c-2/2-0063/power_level').read()
        ge = ge.strip()
        return ge

def funcHeadphoneState():
        print "** Start Function - Headphone State **"
        gl = os.popen('cat /sys/devices/platform/gpio-switch/headphone/state').read()
        gl = gl.strip()
        return gl

def funcKeySlider():
        print "** Start Function - Keyboard Slider State **"
        gl = os.popen('cat /sys/devices/platform/gpio-switch/slide/state').read()
        gl = gl.strip()
        return gl

def funcProxState():
        print " ** Start Function - proximity sensor state**"
        gl = os.popen('cat /sys/devices/platform/gpio-switch/proximity/state').read()
        gl = gl.strip()
        return gl

def funcSysUptime():
        print "** Start Function - system uptime**"
        ge = os.popen('uptime | sed -e \'s/.*p *//\' -e \'s/, l.*//\' -e \'s/  / /\'').read()
        return ge

def funcCurrentCPUFreq():
        print "** Start Function - CPU Frequency **"
        gl = os.popen('echo $((`cat /sys/devices/system/cpu/cpu0/cpufreq/scaling_cur_freq`/1000)) MHz').read()
        gl = gl.strip()
        return gl

def funcAppUsed():
        print "** Start Function - App Used **"
        gl = os.popen('df /home | awk \'/ho/ {print $5}\'').read()
        gl = gl.strip()
        return gl

def funcAppFree():
        print "** Start Function - App Free **"
        gl = os.popen('df -h /home | awk \'/ho/ {print $4}\'').read()
        gl = gl.strip()
        return gl

def funcBacklightAct():
        print "** Start Function - Backlight Info **"
        gl = os.popen('cat /sys/class/backlight/acx565akm/brightness').read()
        gl = gl.strip()
        return gl

def funcBacklightMax():
        print "** Start Function - Backlight Info MAX **"
        gl = os.popen('cat /sys/class/backlight/acx565akm/max_brightness').read()
        gl = gl.strip()
        return gl

def funcKernelInfo():
        print "** Start Function - Kernel Core Info **"
        gl = os.popen('cat /sys/kernel/vmcoreinfo').read()
        return gl.strip()

def funcBootCount():
        print "** Start Function - boot count**"
        gd = os.popen('cat /var/lib/dsme/boot_count').read()
        gd = gd.strip()
        return gd

def funcBootReason():
        print "** Start Function - Boot Reason**"
        gl = os.popen('cat /proc/bootreason').read()
        gl = gl.strip()
        return gl

def funcMMCState():
        print "** Start Function - MMC Cover/latch **"
        gl = os.popen('cat /sys/class/mmc_host/mmc0/cover_switch').read()
        gl = gl.strip()
        return gl

def funcMemoryCUsed():
        print "** Start Function - Memory Card Used **"
        gl = os.popen('df /media/mmc1 | awk \'/mm/ {print $5}\'').read()
        gl = gl.strip()
        return gl

def funcMemoryCFree():
        print "** Start Function - Memory Card Free **"
        gl = os.popen('df -h /media/mmc1 | awk \'/mm/ {print $4}\'').read()
        gl = gl.strip()
        return gl

def funcMyDocsUsed():
        print "** Start Function - MyDocs % Used **"
        gl = os.popen('df /home/user/MyDocs | awk \'/My/ {print $5}\'').read()
        gl = gl.strip()
        return gl

def funcMyDocsFree():
        print "** Start Function - myDocs MB Free **"
        gl = os.popen('df -h /home/user/MyDocs | awk \'/My/ {print $4}\'').read()
        gl = gl.strip()
        return gl

def funcRootUsed():
        print "** Start Function - rootfs % used **"
        gl = os.popen('df | awk \'$1 == "rootfs" {print $5}\'').read()
        gl = gl.strip()
        return gl

def funcRootFree():
        print "** Start Function - rootfs free MB **"
        gl = os.popen('df -h | awk \'$1 == "rootfs" {print $4}\'').read()
        gl = gl.strip()
        return gl

def funcSysLoad():
        print "** Start Function - load from uptime **"
        ge = os.popen('uptime | sed \'s/.*e: //\'').read()
        return ge

def funcDevOri():
        print "** Start Function - Device Orientation **"
        bus = dbus.SystemBus()             
        accel = bus.get_object('com.nokia.mce','/com/nokia/mce/request','com.nokia.mce.request') 
        orientation , stand , face , x , y , z = accel.get_device_orientation()
        return orientation

def funcCPUfreq():
        print "** Start Function - CPU Frequency File **"
        fh = open("/sys/devices/system/cpu/cpu0/cpufreq/scaling_available_frequencies","r")
        igot = fh.readlines()
        print "** Adding CPUQ Frequencies **"
        aa = ""
        counter = 0
        for line in igot:
                s = line.split()
                for words in s:
                        counter = counter +1
                        if counter == 5:
                                aa = str(aa) +"\n \t\t\t\t"
                        if counter == 9:
                                aa = str(aa) +"\n \t\t\t\t"
                        if counter == 13:
                                aa = str(aa) +"\n \t\t\t\t"
                        aa = str(aa) + str((int(words)/1000)) + "MHz, "
        aa = aa.strip()[:-1]
        return aa

def funcMaemoVersion():
        print "** Start Function - firmware version **"
        # This one reads fremantle version number (Firmware)
        g = os.popen('dpkg -l "mp-fremantle-*" | grep ii').read()
        g = g.strip()
        s = g.split()
        g = s[2].strip()
        
        if g.strip() == "3.2010.02-8":
                versionNo = g.strip() + " - PR 1.1.1"
        elif g.strip() == "10.2010.19-1":
                versionNo = g.strip() + " - PR 1.2"
        elif g.strip() == "10.2010.19-1.002":
                versionNo = g.strip() + " - PR 1.2 - USA Version"
        elif g.strip() == "10.2010.19-1.003":
                versionNo = g.strip() + " - PR 1.2 - Middle East and N Africa"
        elif g.strip() == "10.2010.19-1.004":
                versionNo = g.strip() + " - PR 1.2 - India Version"
        elif g.strip() == "10.2010.19-1.201.3":
                versionNo = g.strip() + " - PR 1.2 - UK Version"
        elif g.strip() == "10.2010.19-1.203.1":
                versionNo = g.strip() + " - PR 1.2 - UK Version"
        elif g.strip() == "10.2010.12-9":
                versionNo = g.strip() + " - PR 1.2 - Leaky Release"
        elif g.strip() == "10.2010.12-9":
                versionNo = g.strip() + " - PR 1.2 - Leaky Release"
        elif g.strip() == "10.2010.12-9.1":
                versionNo = g.strip() + " - PR 1.2 - Leaky Release"
        elif g.strip() == "10.2010.12-9.2":
                versionNo = g.strip() + " - PR 1.2 - Leaky Release"
        elif g.strip() == "10.2010.12-9.3":
                versionNo = g.strip() + " - PR 1.2 - Leaky Release"
        elif g.strip() == "10.2010.12-9.001":
                versionNo = g.strip() + " - PR 1.2 - Leaky Release"
        elif g.strip() == "3.2010.02-8.002":
                versionNo = g.strip() + " - PR 1.1.1"
        elif g.strip() == "3.2010.02-8.001":
                versionNo = g.strip() + " - PR 1.1.1"
        elif g.strip() == "2.2009.51-1":
                versionNo = g.strip() + " - PR 1.1"
        elif g.strip() == "2009.51-1.203.2":
                versionNo = g.strip() + " - PR 1.1 UK Generic Version"
        elif g.strip() == "2009.51-1.203.1":
                versionNo = g.strip() + " - PR 1.1 UK Generic Version"
        elif g.strip() == "2009.51-1.205.1":
                versionNo = g.strip() + " - PR 1.1 UK Vodafone Version"
        elif g.strip() == "2009.51-1.205.2":
                versionNo = g.strip() + " - PR 1.1 UK Vodafone Version"
        elif g.strip() == "1.2009.44-1":
                versionNo = g.strip() + " - PR 1.01"
        elif g.strip() == "1.2009.42-11":
                versionNo = g.strip() + " - PR 1 - Initial public release "
        elif g.strip() == "1.2009.42-11.002":
                versionNo = g.strip() + " - PR 1 USA Version"
        elif g.strip() == "1.2009.42-11.003":
                versionNo = g.strip() + " - PR 1 Mid-East/N-Africa Version"
        elif g.strip() == "1.2009.42-11.203":
                versionNo = g.strip() + " - PR 1 UK Generic Version"
        elif g.strip() == "1.2009.42-11.203.0":
                versionNo = g.strip() + " - PR 1 UK Generic Version"
        elif g.strip() == "1.2009.42-11.203.1":
                versionNo = g.strip() + " - PR 1 UK Generic Version"
        elif g.strip() == "1.2009.42-11.203.2":
                versionNo = g.strip() + " - PR 1 UK Generic Version"
        elif g.strip() == "1.2009.42-11.205":
                versionNo = g.strip() + " - PR 1 UK Vodafone Version"
        elif g.strip() == "1.2009.42-11.205.0":
                versionNo = g.strip() + " - PR 1 UK Vodafone Version"
        elif g.strip() == "1.2009.42-11.205.1":
                versionNo = g.strip() + " - PR 1 UK Vodafone Version"
        elif g.strip() == "1.2009.42-11.205.2":
                versionNo = g.strip() + " - PR 1 UK Vodafone Version"
        elif g.strip() == "1.2009.41-1":
                versionNo = g.strip() + " - Early Release Vanilla Variant"
        else:
                versionNo = g.strip()
        return versionNo

def funcProcInfo():
        print "** Start Function - Processor Information **"
        # This one reads fremantle version number (Firmware)
        ga = os.popen('cat /proc/cpuinfo | grep Processor').read()	
        return ga.strip()[11:]

def funcN900Board():
        print "** Start Function - N900 Board Information **"
        gb = os.popen('cat /proc/cpuinfo | grep Hardware').read()
        return gb.strip()[11:]

def funcBoardVer():
        print "** Start Function - Board Version **"
        gj = os.popen('cat /proc/cpuinfo | grep Revision').read()
        return gj.strip()[11:]

def funcSysLocale():
        print "** Start Function - System Locale **"
	gc = os.popen('locale | grep LANG').read()
	return gc.strip()[5:]

def funcHostName():
        print "** Start Function - Device Hostname **"
        ga = os.popen('cat /etc/hostname').read()
        return ga.strip()

def funcIMEI():
        print "** Start Function - Device IMEI **"
        b = os.popen('run-standalone.sh dbus-send --system --print-reply --type=method_call --dest=com.nokia.phone.SIM /com/nokia/phone/SIM/security Phone.Sim.Security.get_imei').read()
        b = str(b)
        b = b.strip()
        b = str(b)[-27:]
        b = b.strip()
        b = str(b)[:-12]
        return b

def funcInternalIP():
        print "** Start Function - Internal IP **"
        ga = os.popen('/sbin/ifconfig | awk \'/Bc/ {print $2}\' | cut -c6-').read()
        return ga.strip()

def funcWifiLinkQ():
        print "** Start Function - Wireless Link Quality **"
        ga = os.popen('cat /proc/net/wireless | awk \'/0/ {print $3}\' | awk -F. \'/./ {print $1" %"}\'').read()
        return ga.strip()

def funcWifiRSSI():
        print "** Start Function - Wireless RSSI **"
        ga = os.popen('cat /proc/net/wireless | awk \'/0/ {print $4" dBm"}\'').read()
        return ga.strip()

def funcWifiNoise():
        print "** Start Function - Wireless Noise **"
        ga = os.popen('cat /proc/net/wireless | awk \'/0/ {print $5}\' | awk -F. \'/./ {print $1" dBm"}\'').read()
        return ga.strip()

def funcMacAddress():
        print "** Start Function - MAC Address **"
        gl = os.popen('cat /sys/class/ieee80211/phy0/macaddress').read()
        return gl.strip()

def funcBluetooth():
        print "** Start Function - Bluetooth Name **"
        gl = os.popen('grep \'^Name =\' /etc/bluetooth/main.conf').read()
        return gl.strip()[7:]

def funcBluetoothMAC():
        print "** Start Function - Bluetooth MAC**"
        gl = os.popen('/usr/sbin/hciconfig hci0 | grep BD').read()            
        s = gl.split(" ")
        return s[2].strip()

==> healthcheck_1.2.1-1.tar.gz: healthcheck-1.2.1/src/opt/healthcheck/gn_functions.py <==
# -*- coding: utf-8 -*-
import os
import dbus

def funcAccel():
	print "** Start Function - Accel Co-ords **"
        f = open("/sys/class/i2c-adapter/i2c-3/3-001d/coord", 'r')
        coords = [int(w) for w in f.readline().split()]
        f.close()
        print " ** Getting orientation**"
        b = os.popen('run-standalone.sh dbus-send --system --type=signal /com/nokia/mce/signal com.nokia.mce.signal.sig_device_orientation_ind').read()
        coords = str(coords)
        jaccel = str(coords) + str(b)
	return jaccel

def funcBatchrg():
        print "** Start Function - Battery Charge **"
        gl = os.popen('hal-device bme | awk \'/l.p/ {perc = $3}; /s_c/ {isch = $3} END if (isch == "false") {print perc" %"} else {print "Charging"}\'').read()
        gl = gl.strip()
        return gl

def funcBatLastChrg():
        print " ** Start Function - battery last charge**"
	gl = os.popen('hal-device bme | awk \'/g.la/ {print $3" mAh"}\'').read()
	return gl.strip()

def funcBattcurr():
        print "** Start Function - Battery Current **"
        gl = os.popen('hal-device bme | awk \'/g.c/ {print $3" mAh"}\'').read()
        gl = gl.strip()
        return gl

def funcCamState():
        print "** Start Function - Cam Shutter State **"
        gl = os.popen('cat /sys/devices/platform/gpio-switch/cam_shutter/state').read()
        gl = gl.strip()
        return gl

def funcFMTrans():
        print "** Start Function - FM Transmitter power level **"
        ge = os.popen('cat /sys/class/i2c-adapter/i2c-2/2-0063/power_level').read()
        ge = ge.strip()
        return ge

def funcHeadphoneState():
        print "** Start Function - Headphone State **"
        gl = os.popen('cat /sys/devices/platform/gpio-switch/headphone/state').read()
        gl = gl.strip()
        return gl

def funcKeySlider():
        print "** Start Function - Keyboard Slider State **"
        gl = os.popen('cat /sys/devices/platform/gpio-switch/slide/state').read()
        gl = gl.strip()
        return gl

def funcProxState():
        print " ** Start Function - proximity sensor state**"
        gl = os.popen('cat /sys/devices/platform/gpio-switch/proximity/state').read()
        gl = gl.strip()
        return gl

def funcSysUptime():
        print "** Start Function - system uptime**"
        ge = os.popen('uptime | sed -e \'s/.*p *//\' -e \'s/, l.*//\' -e \'s/  / /\'').read()
        return ge

def funcCurrentCPUFreq():
        print "** Start Function - CPU Frequency **"
        gl = os.popen('echo $((`cat /sys/devices/system/cpu/cpu0/cpufreq/scaling_cur_freq`/1000)) MHz').read()
        gl = gl.strip()
        return gl

def funcAppUsed():
        print "** Start Function - App Used **"
        gl = os.popen('df /home | awk \'/ho/ {print $5}\'').read()
        gl = gl.strip()
        return gl

def funcAppFree():
        print "** Start Function - App Free **"
        gl = os.popen('df -h /home | awk \'/ho/ {print $4}\'').read()
        gl = gl.strip()
        return gl

def funcBacklightAct():
        print "** Start Function - Backlight Info **"
        gl = os.popen('cat /sys/class/backlight/acx565akm/brightness').read()
        gl = gl.strip()
        return gl

def funcBacklightMax():
        print "** Start Function - Backlight Info MAX **"
        gl = os.popen('cat /sys/class/backlight/acx565akm/max_brightness').read()
        gl = gl.strip()
        return gl

def funcKernelInfo():
        print "** Start Function - Kernel Core Info **"
        gl = os.popen('cat /sys/kernel/vmcoreinfo').read()
        return gl.strip()

def funcBootCount():
        print "** Start Function - boot count**"
        gd = os.popen('cat /var/lib/dsme/boot_count').read()
        gd = gd.strip()
        return gd

def funcBootReason():
        print "** Start Function - Boot Reason**"
        gl = os.popen('cat /proc/bootreason').read()
        gl = gl.strip()
        return gl

def funcMMCState():
        print "** Start Function - MMC Cover/latch **"
        gl = os.popen('cat /sys/class/mmc_host/mmc0/cover_switch').read()
        gl = gl.strip()
        return gl

def funcMemoryCUsed():
        print "** Start Function - Memory Card Used **"
        gl = os.popen('df /media/mmc1 | awk \'/mm/ {print $5}\'').read()
        gl = gl.strip()
        return gl

def funcMemoryCFree():
        print "** Start Function - Memory Card Free **"
        gl = os.popen('df -h /media/mmc1 | awk \'/mm/ {print $4}\'').read()
        gl = gl.strip()
        return gl

def funcMyDocsUsed():
        print "** Start Function - MyDocs % Used **"
        gl = os.popen('df /home/user/MyDocs | awk \'/My/ {print $5}\'').read()
        gl = gl.strip()
        return gl

def funcMyDocsFree():
        print "** Start Function - myDocs MB Free **"
        gl = os.popen('df -h /home/user/MyDocs | awk \'/My/ {print $4}\'').read()
        gl = gl.strip()
        return gl

def funcRootUsed():
        print "** Start Function - rootfs % used **"
        gl = os.popen('df | awk \'$1 == "rootfs" {print $5}\'').read()
        gl = gl.strip()
        return gl

def funcRootFree():
        print "** Start Function - rootfs free MB **"
        gl = os.popen('df -h | awk \'$1 == "rootfs" {print $4}\'').read()
        gl = gl.strip()
        return gl

def funcSysLoad():
        print "** Start Function - load from uptime **"
        ge = os.popen('uptime | sed \'s/.*e: //\'').read()
        return ge

def funcDevOri():
        print "** Start Function - Device Orientation **"
        bus = dbus.SystemBus()             
        accel = bus.get_object('com.nokia.mce','/com/nokia/mce/request','com.nokia.mce.request') 
        orientation , stand , face , x , y , z = accel.get_device_orientation()
        return orientation

def funcCPUfreq():
        print "** Start Function - CPU Frequency File **"
        fh = open("/sys/devices/system/cpu/cpu0/cpufreq/scaling_available_frequencies","r")
        igot = fh.readlines()
        print "** Adding CPUQ Frequencies **"
        aa = ""
        counter = 0
        for line in igot:
                s = line.split()
                for words in s:
                        counter = counter +1
                        if counter == 5:
                                aa = str(aa) +"\n \t\t\t\t"
                        if counter == 9:
                                aa = str(aa) +"\n \t\t\t\t"
                        if counter == 13:
                                aa = str(aa) +"\n \t\t\t\t"
                        aa = str(aa) + str((int(words)/1000)) + "MHz, "
        aa = aa.strip()[:-1]
        return aa

def funcMaemoVersion():
        print "** Start Function - firmware version **"
        # This one reads fremantle version number (Firmware)
        g = os.popen('dpkg -l "mp-fremantle-*" | grep ii').read()
        g = g.strip()
        s = g.split()
        g = s[2].strip()
        
        if g.strip() == "3.2010.02-8":
                versionNo = g.strip() + " - PR 1.1.1"
        elif g.strip() == "10.2010.19-1":
                versionNo = g.strip() + " - PR 1.2"
        elif g.strip() == "10.2010.19-1.002":
                versionNo = g.strip() + " - PR 1.2 - USA Version"
        elif g.strip() == "10.2010.19-1.003":
                versionNo = g.strip() + " - PR 1.2 - Middle East and N Africa"
        elif g.strip() == "10.2010.19-1.004":
                versionNo = g.strip() + " - PR 1.2 - India Version"
        elif g.strip() == "10.2010.19-1.201.3":
                versionNo = g.strip() + " - PR 1.2 - UK Version"
        elif g.strip() == "10.2010.19-1.203.1":
                versionNo = g.strip() + " - PR 1.2 - UK Version"
        elif g.strip() == "10.2010.12-9":
                versionNo = g.strip() + " - PR 1.2 - Leaky Release"
        elif g.strip() == "10.2010.12-9":
                versionNo = g.strip() + " - PR 1.2 - Leaky Release"
        elif g.strip() == "10.2010.12-9.1":
                versionNo = g.strip() + " - PR 1.2 - Leaky Release"
        elif g.strip() == "10.2010.12-9.2":
                versionNo = g.strip() + " - PR 1.2 - Leaky Release"
        elif g.strip() == "10.2010.12-9.3":
                versionNo = g.strip() + " - PR 1.2 - Leaky Release"
        elif g.strip() == "10.2010.12-9.001":
                versionNo = g.strip() + " - PR 1.2 - Leaky Release"
        elif g.strip() == "3.2010.02-8.002":
                versionNo = g.strip() + " - PR 1.1.1"
        elif g.strip() == "3.2010.02-8.001":
                versionNo = g.strip() + " - PR 1.1.1"
        elif g.strip() == "2.2009.51-1":
                versionNo = g.strip() + " - PR 1.1"
        elif g.strip() == "2009.51-1.203.2":
                versionNo = g.strip() + " - PR 1.1 UK Generic Version"
        elif g.strip() == "2009.51-1.203.1":
                versionNo = g.strip() + " - PR 1.1 UK Generic Version"
        elif g.strip() == "2009.51-1.205.1":
                versionNo = g.strip() + " - PR 1.1 UK Vodafone Version"
        elif g.strip() == "2009.51-1.205.2":
                versionNo = g.strip() + " - PR 1.1 UK Vodafone Version"
        elif g.strip() == "1.2009.44-1":
                versionNo = g.strip() + " - PR 1.01"
        elif g.strip() == "1.2009.42-11":
                versionNo = g.strip() + " - PR 1 - Initial public release "
        elif g.strip() == "1.2009.42-11.002":
                versionNo = g.strip() + " - PR 1 USA Version"
        elif g.strip() == "1.2009.42-11.003":
                versionNo = g.strip() + " - PR 1 Mid-East/N-Africa Version"
        elif g.strip() == "1.2009.42-11.203":
                versionNo = g.strip() + " - PR 1 UK Generic Version"
        elif g.strip() == "1.2009.42-11.203.0":
                versionNo = g.strip() + " - PR 1 UK Generic Version"
        elif g.strip() == "1.2009.42-11.203.1":
                versionNo = g.strip() + " - PR 1 UK Generic Version"
        elif g.strip() == "1.2009.42-11.203.2":
                versionNo = g.strip() + " - PR 1 UK Generic Version"
        elif g.strip() == "1.2009.42-11.205":
                versionNo = g.strip() + " - PR 1 UK Vodafone Version"
        elif g.strip() == "1.2009.42-11.205.0":
                versionNo = g.strip() + " - PR 1 UK Vodafone Version"
        elif g.strip() == "1.2009.42-11.205.1":
                versionNo = g.strip() + " - PR 1 UK Vodafone Version"
        elif g.strip() == "1.2009.42-11.205.2":
                versionNo = g.strip() + " - PR 1 UK Vodafone Version"
        elif g.strip() == "1.2009.41-1":
                versionNo = g.strip() + " - Early Release Vanilla Variant"
        else:
                versionNo = g.strip()
        return versionNo

def funcProcInfo():
        print "** Start Function - Processor Information **"
        # This one reads fremantle version number (Firmware)
        ga = os.popen('cat /proc/cpuinfo | grep Processor').read()	
        return ga.strip()[11:]

def funcN900Board():
        print "** Start Function - N900 Board Information **"
        gb = os.popen('cat /proc/cpuinfo | grep Hardware').read()
        return gb.strip()[11:]

def funcBoardVer():
        print "** Start Function - Board Version **"
        gj = os.popen('cat /proc/cpuinfo | grep Revision').read()
        return gj.strip()[11:]

def funcSysLocale():
        print "** Start Function - System Locale **"
	gc = os.popen('locale | grep LANG').read()
	return gc.strip()[5:]

def funcHostName():
        print "** Start Function - Device Hostname **"
        ga = os.popen('cat /etc/hostname').read()
        return ga.strip()

def funcIMEI():
        print "** Start Function - Device IMEI **"
        b = os.popen('run-standalone.sh dbus-send --system --print-reply --type=method_call --dest=com.nokia.phone.SIM /com/nokia/phone/SIM/security Phone.Sim.Security.get_imei').read()
        b = str(b)
        b = b.strip()
        b = str(b)[-27:]
        b = b.strip()
        b = str(b)[:-12]
        return b

def funcInternalIP():
        print "** Start Function - Internal IP **"
        ga = os.popen('/sbin/ifconfig | awk \'/Bc/ {print $2}\' | cut -c6-').read()
        return ga.strip()

def funcWifiLinkQ():
        print "** Start Function - Wireless Link Quality **"
        ga = os.popen('cat /proc/net/wireless | awk \'/0/ {print $3}\' | awk -F. \'/./ {print $1" %"}\'').read()
        return ga.strip()

def funcWifiRSSI():
        print "** Start Function - Wireless RSSI **"
        ga = os.popen('cat /proc/net/wireless | awk \'/0/ {print $4" dBm"}\'').read()
        return ga.strip()

def funcWifiNoise():
        print "** Start Function - Wireless Noise **"
        ga = os.popen('cat /proc/net/wireless | awk \'/0/ {print $5}\' | awk -F. \'/./ {print $1" dBm"}\'').read()
        return ga.strip()

def funcMacAddress():
        print "** Start Function - MAC Address **"
        gl = os.popen('cat /sys/class/ieee80211/phy0/macaddress').read()
        return gl.strip()

def funcBluetooth():
        print "** Start Function - Bluetooth Name **"
        gl = os.popen('grep \'^Name =\' /etc/bluetooth/main.conf').read()
        return gl.strip()[7:]

def funcBluetoothMAC():
        print "** Start Function - Bluetooth MAC**"
        gl = os.popen('/usr/sbin/hciconfig hci0 | grep BD').read()            
        s = gl.split(" ")
        return s[2].strip()

def funcCPUMinMax():
        print "** Start Function - Bluetooth MAC**"
        a = os.popen('cat /sys/devices/system/cpu/cpu0/cpufreq/scaling_max_freq').read()
        a = a.strip()
        a = int(a) / 1000
        b = os.popen('cat /sys/devices/system/cpu/cpu0/cpufreq/scaling_min_freq').read()
        b = b.strip()
        b = int(b) / 1000
        c = str(b) + "MHz" + " / " + str(a) + "MHz"
        return c.strip()
